#!/bin/sh

# Author: Zhang Huangbin (michaelbibby <at> gmail.com)
# Modified by A.Lang (alang.hsu <at> gmail.com)

# Note: config file will be sourced in 'conf/functions', check_env().

. ./conf/global
. ./conf/functions
. ./conf/asterisk

trap "exit 255" 2

check_arch

# Initialize config file.
echo '' > ${CONFIG_FILE}

DIALOG='dialog --no-collapse'
DIALOG_BACKTITLE="${PROG_NAME} ${PROG_VERSION}: Install Audio Codecs Wizard for Elastix/Asterisk"

# Welcome message.
${DIALOG} --backtitle "${DIALOG_BACKTITLE}" \
    --title "Welcome and thanks for use" \
    --msgbox "\
Thanks for your use of ${PROG_NAME}.
Feedback, bug report, communication are all welcome.

Contact me if you need help for ${PROG_NAME} or Elastix/Asterisk:

    * Author:   Zhang Huangbin
    * Mail:     michaelbibby (at) gmail.com
    - Modifier: A.Lang
    - Mail:     alang.hs (at) gmail.com
    - Support:  www.osslab.org.tw

NOTE:

    Ctrl-C will abort this wizard.
" 22 76

# AST_MODULE_DIR
${DIALOG} --backtitle "${DIALOG_BACKTITLE}" \
    --title "MODULE directory of Asterisk" \
    --inputbox "\
Please specify the MODULE directory of Asterisk: 
Usually, the default is ${AST_MODULE_DIR}.

EXAMPLE:

    * ${AST_MODULE_DIR}

NOTE:
The default directory will be used in Elastix/Trixbox. \
For other ones, you may have to specify the actual path of \
asterisk's modules.
" 22 76 "${AST_MODULE_DIR}" 2>/tmp/ast_module_dir

AST_MODULE_DIR="$(cat /tmp/ast_module_dir)"
export AST_MODULE_DIR="${AST_MODULE_DIR}" && echo "export AST_MODULE_DIR='${AST_MODULE_DIR}'" >>${CONFIG_FILE}
rm -f /tmp/ast_module_dir


# Choose codecs you will install 
${DIALOG} --backtitle "${DIALOG_BACKTITLE}" \
    --title "Choose your prefer codecs" \
    --checklist "\
Here provide two codecs to install:

    +-------+-------+
    | G.729 | G.723 |
    +-------+-------+

NOTE:
Theses codecs are for 'educational' purpose only and you will \
need to purchase a license if you plan to use them in any system.

TIP:
Use 'Space' key to select item.

" 22 76 2 \
    "g729" "The G.729 codec. " on \
    "g723" "The G.723 codec. " on \
    2>/tmp/codecs

CODECS="$(cat /tmp/codecs | sed 's/\"//g')"
echo "export CODECS='${CODECS}'" >> ${CONFIG_FILE}
#rm -f /tmp/codecs

#if [ X"${CODECS}" == X"OpenLDAP" ]; then
#    . ${DIALOG_DIR}/ldap_config.sh
#elif [ X"${CODECS}" == X"MySQL" ]; then
#    . ${DIALOG_DIR}/mysql_config.sh
#else
#    :
#fi


# Choose CPU type you are using
${DIALOG} --backtitle "${DIALOG_BACKTITLE}" \
    --title "Please Choose the proper CPU Type" \
    --menu "\
The detected CPU model is on system:

<Model Name>: $CPU_MODEL
<CPU Flags> : $CPU_FLAGS

NOTE:
Please be careful to select the CPU type. If it cause asterisk to \
coredump situation, just uninstall it then reinstall the other models.

" 22 76 7 \
    "athlon-sse" "The AMD Athlon processor with sse. " \
    "atom" "The Intel Atom processor. " \
    "core2" "The Intel Core2 Dual processor. " \
    "core2-sse4" "The Intel Core2 Dual processor with sse4. " \
    "opteron" "The AMD Opteron processor. " \
    "opteron-sse3" "The AMD Opteron processor with sse3. " \
    "pentium" "The Pentium processor. " \
    "pentium2" "The Pentium II processor. " \
    "pentium3" "The general Pentimu III processor. " \
    "pentium3-no-sse" "The Pentium III processor without sse. " \
    "pentium4" "The general Pentium 4 processor. " \
    "pentium4-no-sse" "The Pentium 4 processor without sse. " \
    "pentium4-sse3" "The Pentium 4 processor with sse3. " \
    2>/tmp/cpu_type

CPU_TYPE="$(cat /tmp/cpu_type)"
echo "export CPU_TYPE='${CPU_TYPE}'" >> ${CONFIG_FILE}
rm -f /tmp/cpu_type

# The message for confirmation.
${DIALOG} --backtitle "${DIALOG_BACKTITLE}" \
    --title "Confirm the configuration you finished " \
    --msgbox "\
If the following information are correct, press OK to continue the installation or press 'CTRL-C' abort this wizard.

 AST_VER='$AST_VER'
$(cat ${CONFIG_FILE}|sed '/^$/d'|sed 's/export//g')

NOTE:

    Ctrl-C will abort this wizard.
" 22 76



