#!/bin/sh

# Author: Zhang Huangbin (michaelbibby <at> gmail.com)
# Modified by A.Lang (alang.hsu <at> gmail.com)

codec_install()
{
  # For asterisk version 1.2.x
  AST_VER_12="$(echo $AST_VER | sed -n '/^1\.2\./p')"

  # For asterisk version 1.4.x 
  AST_VER_14="$(echo $AST_VER | sed -n '/^1\.4\./p')"

  # For asterisk version 1.6.0
  AST_VER_160="$(echo $AST_VER | sed -n '/^1\.6\.0[\.\-\_]/p')"

  # For asterisk version 1.6.1
  AST_VER_161="$(echo $AST_VER | sed -n '/^1\.6\.1[\.\-\_]/p')"

  AST_MODULE_SHOW_OPT="module show"
  AST_MODULE_SHOW_LIKE_OPT="module show like"
  AST_MODULE_LOAD_OPT="module load"

  if [ ! -z ${AST_VER_12} ]; then
     AST_VER_WGET="ast12"
     CODECS_URL="http://asterisk.hosting.lv/bin12"
     AST_MODULE_SHOW_OPT="show module"
     AST_MODULE_LOAD_OPT="load"
  elif [ ! -z ${AST_VER_14} ]; then
     AST_VER_WGET="ast14"
     CODECS_URL="http://asterisk.hosting.lv/bin" 
     AST_MODULE_SHOW_OPT="module show"
     AST_MODULE_LOAD_OPT="module load"
  elif [ ! -z ${AST_VER_160} ]; then
     AST_VER_WGET="ast16"
     CODECS_URL="http://asterisk.hosting.lv/bin160"
     AST_MODULE_SHOW_OPT="module show"
     AST_MODULE_LOAD_OPT="module load"
  elif [ ! -z ${AST_VER_161} ]; then
     AST_VER_WGET="ast16"
     CODECS_URL="http://asterisk.hosting.lv/bin"
     AST_MODULE_SHOW_OPT="module show"
     AST_MODULE_LOAD_OPT="module load"
  else
     ECHO_INFO "*Warning: Asterisk version is $AST_VER, but can't found the proper download link!"
     exit 255
  fi

  # get the codec library file from Internet
  cd $MISC_DIR
  
  AST_MODULE_RELOAD="FALSE"
  AST_MODULE_FILES=''
  for i in $CODECS; 
  do
     FILE_NAME_WGET="codec_$i-$AST_VER_WGET-gcc4-glibc-$CPU_TYPE.so"
     CODECS_WGET="$CODECS_URL/$FILE_NAME_WGET"
     FILE_NAME_MOD="osslab-codec_$i.so"

     wget $CODECS_WGET

     if [ X"$?" == X"0" ]; then
        ECHO_INFO_STATS "Download $i codec file." "OK"
        mv -f $FILE_NAME_WGET $AST_MODULE_DIR/$FILE_NAME_MOD
        chown asterisk:asterisk $AST_MODULE_DIR/$FILE_NAME_MOD
        chmod 644 $AST_MODULE_DIR/$FILE_NAME_MOD
        AST_MODULE_RELOAD="TRUE"
        AST_MODULE_FILES="$FILE_NAME_MOD $AST_MODULE_FILES"
     else
        ECHO_INFO_STATS "*Download $i codec file." "Fail" 
     fi
  done

  if [ X"$AST_MODULE_RELOAD" == X"TRUE" ]; then
     AST_MODULE_RELOAD_STATUS="OK"
     for j in $AST_MODULE_FILES
     do
        asterisk -rx "$AST_MODULE_LOAD_OPT $j" 
        AST_SHOW_MODULE="$(asterisk -rx "$AST_MODULE_SHOW_OPT" | grep $j)"
        if [ -z "$AST_SHOW_MODULE" ]; then
           [ X"$AST_MODULE_RELOAD_STATUS" == X"OK" ] && AST_MODULE_RELOAD_STATUS="FAIL"
           ECHO_INFO_STATS "*Loading module files ($j)." "Fail"
           ECHO_INFO "Clean the module files ($j)"
           rm -f $AST_MODULE_DIR/$j
        else
           ECHO_INFO_STATS "Loading module files ($j)." "OK"
        fi
     done
     if [ X"$AST_MODULE_RELOAD_STATUS" != X"FAIL" ]; then
        ECHO_INFO "The list of Module Show :"
        asterisk -rx "$AST_MODULE_SHOW_OPT like osslab"
        ECHO_INFO "--------------------------------------\n \
Success and Done."
     else
        ECHO_INFO "*Abort the installation!"
     fi
  else
     :
  fi
}

